@@ -7,8 +7,9 @@ from trytond.wizard import Wizard, StateTransition, StateView, Button
 from trytond.pyson import Eval, Bool, If, Id
 from trytond.pool import Pool
 from trytond.transaction import Transaction
+from trytond import backend
 
-from trytond.modules.product import price_digits
+from trytond.modules.product import price_digits, TemplateFunction
 
 __all__ = ['Production', 'AssignFailed', 'Assign']
 
@@ -19,9 +20,9 @@ BOM_CHANGES = ['bom', 'product', 'quantity', 'uom', 'warehouse', 'location',
 class Production(Workflow, ModelSQL, ModelView):
     "Production"
     __name__ = 'production'
-    _rec_name = 'code'
+    _rec_name = 'number'
 
-    code = fields.Char('Code', select=True, readonly=True)
+    number = fields.Char('Number', select=True, readonly=True)
     reference = fields.Char('Reference', select=1,
         states={
             'readonly': ~Eval('state').in_(['request', 'draft']),
@@ -104,6 +105,7 @@ class Production(Workflow, ModelSQL, ModelView):
             readonly=True), 'get_cost')
     inputs = fields.One2Many('stock.move', 'production_input', 'Inputs',
         domain=[
+            ('shipment', '=', None),
             ('from_location', 'child_of', [Eval('warehouse')], 'parent'),
             ('to_location', '=', Eval('location')),
             ('company', '=', Eval('company', -1)),
@@ -115,6 +117,7 @@ class Production(Workflow, ModelSQL, ModelView):
         depends=['warehouse', 'location', 'company'])
     outputs = fields.One2Many('stock.move', 'production_output', 'Outputs',
         domain=[
+            ('shipment', '=', None),
             ('from_location', '=', Eval('location')),
             ('to_location', 'child_of', [Eval('warehouse')], 'parent'),
             ('company', '=', Eval('company', -1)),
@@ -200,6 +203,17 @@ class Production(Workflow, ModelSQL, ModelView):
                 'assign_force': {},
                 })
 
+    @classmethod
+    def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
+        table_h = TableHandler(cls, module_name)
+
+        # Migration from 3.8: rename code into number
+        if table_h.column_exist('code'):
+            table_h.column_rename('code', 'number')
+
+        super(Production, cls).__register__(module_name)
+
     @staticmethod
     def default_state():
         return 'draft'
@@ -415,6 +429,8 @@ class Production(Workflow, ModelSQL, ModelView):
                 if product == self.product:
                     move.unit_price = Decimal(
                         cost / Decimal(str(quantity))).quantize(digit)
+                else:
+                    move.unit_price = Decimal(0)
                 move.save()
         self._set_move_planned_date()
 
@@ -446,7 +462,9 @@ class Production(Workflow, ModelSQL, ModelView):
         vlist = [x.copy() for x in vlist]
         config = Config(1)
         for values in vlist:
-            values['code'] = Sequence.get_id(config.production_sequence.id)
+            if values.get('number') is None:
+                values['number'] = Sequence.get_id(
+                    config.production_sequence.id)
         productions = super(Production, cls).create(vlist)
         for production in productions:
             production._set_move_planned_date()
@@ -458,6 +476,14 @@ class Production(Workflow, ModelSQL, ModelView):
         for production in sum(args[::2], []):
             production._set_move_planned_date()
 
+    @classmethod
+    def copy(cls, productions, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default.setdefault('number', None)
+        return super(Production, cls).copy(productions, default=default)
+
     def _get_move_planned_date(self):
         "Return the planned dates for input and output moves"
         return self.planned_date, self.planned_date
